# Algorithme LLL


## Description:
### Equipe:
    Carlos-Ariel Vanegas,habile en pogrammation dans de multiples languages.  
### Idee:
    une Librairie implementant l'algorithme LLL et permettant de generer des Lattices
### Utillite: 
    Les Lattices sont etudies entres autres en cryptographie. leur comprehension pourrait permettre de 
### Cas d'utillisation:
    servira a visualiser des Lattices et a completer de la recherche sur le sujet
### Public Cible:   
    Chercheurs en mathemathiques et potentiellement en Cryptographie
### Lien avec d'autres disciplines
    Le projet a un fort lien avec les mathemathiques: il s'agit la de son utilite principale
## Technologies utilises

### Langages de programmation:
  - [Python](https://python.org)
  - C  pour certaines parties critiques
  - [Taichi](https://www.taichi-lang.org) (Librairie) pour certains graphismes
  - Librairie [PyQt6](https://pypi.org/project/PyQt6) pour les exemples d'utilisation
### Difficultes
  - Comprehension des mathemathiques necessaires
  - Gestion de memoire et des interfaces entre langages de programmation
  - Implementation performante des algorithmes
 


 
